@@ -25,30 +25,30 @@ HorizontalVolumeBarWidget::HorizontalVolumeBarWidget(QWidget *parent) : VolumeMe
 
 void HorizontalVolumeBarWidget::draw(QPainter *painter){
     float vol;
-    Qt::GlobalColor color = Qt::darkBlue;
+    QColor color = QColor(Qt::darkBlue);
 
     if(dbUnit){
         vol = ((float) currentValue) / MAX_DB;
 
         if(useColoredScale){
-            if(currentValue < 60){
-                color = Qt::green;
-            }else if (currentValue < 95){
-                color = Qt::yellow;
+            if(currentValue < lowerThreshold){
+                color = lowerColor;
+            }else if (currentValue < upperThreshold){
+                color = midColor;
             }else{
-                color = Qt::red;
+                color = upperColor;
             }
         }
     }else{
         vol = ((float) currentValue) / MAX_LINEAR;
 
         if(useColoredScale){
-            if(currentValue < 100){
-                color = Qt::green;
-            }else if (currentValue < 150){
-                color = Qt::yellow;
+            if(currentValue < lowerThreshold){
+                color = lowerColor;
+            }else if (currentValue < upperThreshold){
+                color = midColor;
             }else{
-                color = Qt::red;
+                color = upperColor;
             }
         }
     }
@@ -107,13 +107,18 @@ void HorizontalVolumeBarWidget::prepareBackground(){
         for(int i = 0; i <= (MAX_DB / 10); i++){
             float x = 2.96 * h / (MAX_DB / 10.) * i;
 
-            if(i % 2 == 0){
+            if(i == 0){
                 painter.setPen(thickPen);
                 painter.drawLine((0.04 * h) + x, 0.74 * h, (0.04 * h) + x, 0.8 * h);
 
+                painter.drawText(x, 0.96 * h, QString().setNum(i*10));
+            }else if(i % 2 == 0){
+                painter.setPen(thickPen);
+                painter.drawLine(x - (0.01 * h), 0.74 * h, x - (0.01 * h), 0.8 * h);
+
                 painter.setPen(thinPen);
                 if(i > 0){
-                    x -= 0.04 * h;
+                    x -= 0.08 * h;
                 }
                 if(i >= 10){
                     x -= 0.04 * h;
@@ -124,7 +129,7 @@ void HorizontalVolumeBarWidget::prepareBackground(){
                 painter.setPen(thinPen);
 
                 if(i < 11){
-                    painter.drawLine((0.04 * h) + x, 0.73 * h, (0.04 * h) + x, 0.77 * h);
+                    painter.drawLine(x - (0.01 * h), 0.73 * h, x - (0.01 * h), 0.77 * h);
                 }else{
                     painter.drawLine((0.01 * h) + x, 0.73 * h, (0.01 * h) + x, 0.77 * h);
                 }
@@ -134,14 +139,19 @@ void HorizontalVolumeBarWidget::prepareBackground(){
         for(int i = 0; i <= (MAX_LINEAR / 10); i++){
             float x = 2.96 * h / (MAX_LINEAR / 10.)*i;
 
-            if(i % 5 == 0){
+            if(i == 0){
+                painter.setPen(thickPen);
+                painter.drawLine((0.04 * h) + x, 0.74 * h, (0.04 * h) + x, 0.8 * h);
+
+                painter.drawText(x, 0.96 * h, QString().setNum(i*10));
+            }else if(i % 5 == 0){
                 painter.setPen(thickPen);
                 if(i < 20){
-                    painter.drawLine((0.04 * h) + x, 0.74 * h, (0.04 * h) + x, 0.8 * h);
+                    painter.drawLine(x - (0.01 * h), 0.74 * h, x - (0.01 * h), 0.8 * h);
 
                     painter.setPen(thinPen);
                     if(i > 0){
-                        x -= 0.04 * h;
+                        x -= 0.08 * h;
                     }
                     if(i >= 10){
                         x -= 0.04 * h;
@@ -149,11 +159,11 @@ void HorizontalVolumeBarWidget::prepareBackground(){
 
                     painter.drawText(x, 0.96 * h, QString().setNum(i*10));
                 }else{
-                    painter.drawLine(x, 0.74 * h, x, 0.8 * h);
+                    painter.drawLine(x - (0.01 * h), 0.74 * h, x - (0.01 * h), 0.8 * h);
                 }
             }else{
                 painter.setPen(thinPen);
-                painter.drawLine((0.04 * h) + x, 0.73 * h, (0.04 * h) + x, 0.77 * h);
+                painter.drawLine(x - (0.01 * h), 0.73 * h, x - (0.01 * h), 0.77 * h);
             }
         }
     }
