@@ -294,7 +294,7 @@ void MainWindow::updateValues(float value){
         logIndex++;
     }
 
-    if(triggerValue != 0){
+    if(triggerValue > 0){
         if(vol > triggerValue && process == NULL){
             if(triggerCount >= triggerCountSetting){
                 process = new QProcess();
