@@ -20,23 +20,28 @@
 #include "pa_streams_helper.h"
 #include "pa_utils.h"
 
+#include <cmath>
+
 pa_stream *stream = NULL;
 
-void connect_to_vu_meter_stream(const char* source, MainWindow *vuMeter){
+void connect_to_vu_meter_stream(const char* source, MainWindow *vuMeter, int numberOfSamples){
     pa_buffer_attr attr;
-    attr.fragsize = sizeof(float);
+    attr.fragsize = sizeof(float) * numberOfSamples;
     attr.maxlength = (uint32_t) -1;
 
     pa_sample_spec sample_specification;
     sample_specification.format = PA_SAMPLE_FLOAT32;
-    sample_specification.rate = 25;
+    sample_specification.rate = 25 * numberOfSamples;
     sample_specification.channels = 1;
 
     qDebug("Connecting to VU meter stream...");
     stream = pa_stream_new(context, "VU Meter Stream", &sample_specification, NULL);
 
     pa_stream_set_state_callback(stream, stream_state_callback, vuMeter);
-    pa_stream_connect_record(stream, source, &attr, (pa_stream_flags_t) (PA_STREAM_DONT_MOVE|PA_STREAM_PEAK_DETECT|PA_STREAM_ADJUST_LATENCY));
+    pa_stream_connect_record(stream,
+                             source,
+                             &attr,
+                             (pa_stream_flags_t) (PA_STREAM_DONT_MOVE|PA_STREAM_PEAK_DETECT|PA_STREAM_ADJUST_LATENCY));
 }
 
 void disconnect_stream(){
@@ -52,13 +57,35 @@ void disconnect_stream(){
 
 void stream_read_callback(pa_stream *stream, size_t length, void *data){
     const void *audio_data;
+    float vol = 0;
+    float currentVolume = 0;
+    int n = 0;
+    MainWindow *vuMeter;
+    vuMeter = (MainWindow *) data;
 
     pa_stream_peek(stream, &audio_data, &length);
     pa_stream_drop(stream);
 
-    MainWindow *vuMeter;
-    vuMeter = (MainWindow *) data;
-    vuMeter->updateVuMeter((const float*) audio_data);
+    if(vuMeter->getInterpolationEnabled()){
+        for(size_t i = 0; i < length; i++){
+            currentVolume = ((const float*) audio_data)[i];
+
+            if(currentVolume != 0){
+                vol += fabs(currentVolume);
+                n++;
+            }
+        }
+
+        if(n > 0){
+            vol /= (float) n;
+        }else{
+            vol = 0.;
+        }
+    }else{
+        vol = ((const float*) audio_data)[0];
+    }
+
+    vuMeter->updateVuMeter(&vol);
 }
 
 void stream_state_callback(pa_stream *stream, void *data){
