@@ -20,15 +20,17 @@
 #ifndef PA_STREAMS_HELPER_H
 #define PA_STREAMS_HELPER_H
 
-#include "mainwindow.h"
-
 #include <pulse/context.h>
 #include <pulse/proplist.h>
 #include <pulse/stream.h>
 
+#include "mainwindow.h"
+
 extern pa_stream *stream;
 
-void connect_to_vu_meter_stream(const char *source, MainWindow *vuMeter, int numberOfSamples = 1);
+void connect_to_vu_meter_stream(const char *source,
+                                MainWindow *vuMeter,
+                                int numberOfSamples = 1);
 void disconnect_stream();
 
 void stream_read_callback(pa_stream *stream, size_t length, void *data);
